@@ -238,9 +238,37 @@ class Hourly(Timeseries):
         if self._stations.size == 0 or self._data.size == 0:
             return None
 
+        def adjust_temp(data: pd.DataFrame):
+            """
+            Adjust temperature-like data based on altitude
+            """
+
+            data.loc[data['temp'] != np.NaN, 'temp'] = data['temp'] + \
+                ((2 / 3) * ((data['elevation'] - alt) / 100))
+            data.loc[data['dwpt'] != np.NaN, 'dwpt'] = data['dwpt'] + \
+                ((2 / 3) * ((data['elevation'] - alt) / 100))
+
+            return data
+
         if method == 'nearest':
 
-            self._data = self._data.groupby(pd.Grouper(
+            if adapt_temp:
+
+                # Join elevation of involved weather stations
+                data = self._data.join(
+                    stations['elevation'], on='station')
+
+                # Adapt temperature-like data based on altitude
+                data = adjust_temp(data)
+
+                # Drop elevation & round
+                data = data.drop('elevation', axis=1).round(1)
+
+            else:
+
+                data = self._data
+
+            self._data = data.groupby(pd.Grouper(
                 level='time', freq=self._freq)).agg('first')
 
         else:
@@ -251,10 +279,7 @@ class Hourly(Timeseries):
 
             # Adapt temperature-like data based on altitude
             if adapt_temp:
-                data.loc[data['temp'] != np.NaN, 'temp'] = data['temp'] + \
-                    ((2 / 3) * ((data['elevation'] - alt) / 100))
-                data.loc[data['dwpt'] != np.NaN, 'dwpt'] = data['dwpt'] + \
-                    ((2 / 3) * ((data['elevation'] - alt) / 100))
+                data = adjust_temp(data)
 
             # Exclude non-mean data & perform aggregation
             excluded = data[['wdir', 'coco']]
